===============================
DBaaS NFSaaS integration
===============================

.. image:: https://badge.fury.io/py/dbaas_nfsaas.png
    :target: http://badge.fury.io/py/dbaas_nfsaas


NFSaaS integration for DBaaS

* Documentation: http://dbaas_nfsaas.rtfd.org.

Features
--------

* TODO
